@@ -1,9 +1,8 @@
+require 'pathname'
+
 require 'aruba/platform'
-
 require 'aruba/extensions/string/strip'
 
-require 'aruba/aruba_path'
-
 Aruba.platform.require_matching_files('../matchers/file/*.rb', __FILE__)
 Aruba.platform.require_matching_files('../matchers/directory/*.rb', __FILE__)
 Aruba.platform.require_matching_files('../matchers/path/*.rb', __FILE__)
@@ -40,8 +39,10 @@ module Aruba
 
       # Check if file exist and is executable
       #
-      # @param [String] file
-      #   The file which should exist
+      # @param [String] path
+      #   The path which should exist and be executable
+      #
+      # @return [Boolean]
       def executable?(path)
         path = expand_path(path)
 
@@ -50,18 +51,16 @@ module Aruba
 
       # Check if path is absolute
       #
-      # @return [TrueClass, FalseClass]
-      #   Result of check
+      # @return [Boolean]
       def absolute?(path)
-        ArubaPath.new(path).absolute?
+        Aruba.platform.absolute_path?(path)
       end
 
       # Check if path is relative
       #
-      # @return [TrueClass, FalseClass]
-      #   Result of check
+      # @return [Boolean]
       def relative?(path)
-        ArubaPath.new(path).relative?
+        Aruba.platform.relative_path?(path)
       end
 
       # Return all existing paths (directories, files) in current dir
@@ -69,7 +68,7 @@ module Aruba
       # @return [Array]
       #   List of files and directories
       def all_paths
-        list('.').map { |p| expand_path(p) }
+        list('.').map { |path| expand_path(path) }
       end
 
       # Return all existing files in current directory
@@ -93,7 +92,7 @@ module Aruba
       # @return [Dir]
       #   The directory object
       def directory(path)
-        fail ArgumentError, %(Path "#{name}" does not exist.) unless exist? name
+        raise ArgumentError, %(Path "#{name}" does not exist.) unless exist? name
 
         Dir.new(expand_path(path))
       end
@@ -103,22 +102,31 @@ module Aruba
       # @return [Array]
       #   The content of directory
       def list(name)
-        fail ArgumentError, %(Path "#{name}" does not exist.) unless exist? name
-        fail ArgumentError, %(Only directories are supported. Path "#{name}" is not a directory.) unless directory? name
+        raise ArgumentError, %(Path "#{name}" does not exist.) unless exist? name
+
+        unless directory? name
+          raise ArgumentError,
+                %(Only directories are supported. Path "#{name}" is not a directory.)
+        end
 
         existing_files            = Dir.glob(expand_path(File.join(name, '**', '*')))
-        current_working_directory = ArubaPath.new(expand_path('.'))
+        current_working_directory = Pathname.new(expand_path('.'))
 
-        existing_files.map { |d| ArubaPath.new(d).relative_path_from(current_working_directory).to_s }
+        existing_files.map do |d|
+          Pathname.new(d).relative_path_from(current_working_directory).to_s
+        end
       end
 
       # Return content of file
       #
       # @return [Array]
-      #   The content of file, without "\n" or "\r\n" at the end. To rebuild the file use `content.join("\n")`
+      #   The content of file, without "\n" or "\r\n" at the end.
+      #   To rebuild the file use `content.join("\n")`
       def read(name)
-        fail ArgumentError, %(Path "#{name}" does not exist.) unless exist? name
-        fail ArgumentError, %(Only files are supported. Path "#{name}" is not a file.) unless file? name
+        raise ArgumentError, %(Path "#{name}" does not exist.) unless exist? name
+        unless file? name
+          raise ArgumentError, %(Only files are supported. Path "#{name}" is not a file.)
+        end
 
         File.readlines(expand_path(name)).map(&:chomp)
       end
@@ -128,10 +136,10 @@ module Aruba
       # The method does not check if file already exists. If the file name is a
       # path the method will create all neccessary directories.
       #
-      # @param [String] file_name
+      # @param [String] name
       #   The name of the file
       #
-      # @param [String] file_content
+      # @param [String] content
       #   The content which should be written to the file
       def write_file(name, content)
         Aruba.platform.create_file(expand_path(name), content, false)
@@ -146,7 +154,7 @@ module Aruba
       def touch(*args)
         args = args.flatten
 
-        options = if args.last.kind_of? Hash
+        options = if args.last.is_a? Hash
                     args.pop
                   else
                     {}
@@ -169,9 +177,6 @@ module Aruba
       # @param [String] destination
       #   A file or directory name. If multiple sources are given the destination
       #   needs to be a directory
-      #
-      # rubocop:disable Metrics/CyclomaticComplexity
-      # def copy(*source, destination)
       def copy(*args)
         args = args.flatten
         destination = args.pop
@@ -181,8 +186,14 @@ module Aruba
           raise ArgumentError, %(The following source "#{s}" does not exist.) unless exist? s
         end
 
-        raise ArgumentError, "Using a fixture as destination (#{destination}) is not supported" if destination.start_with? aruba.config.fixtures_path_prefix
-        raise ArgumentError, "Multiples sources can only be copied to a directory" if source.count > 1 && exist?(destination) && !directory?(destination)
+        if destination.start_with? aruba.config.fixtures_path_prefix
+          raise ArgumentError,
+                "Using a fixture as destination (#{destination}) is not supported"
+        end
+
+        if source.count > 1 && exist?(destination) && !directory?(destination)
+          raise ArgumentError, 'Multiples sources can only be copied to a directory'
+        end
 
         source_paths     = source.map { |f| expand_path(f) }
         destination_path = expand_path(destination)
@@ -198,7 +209,6 @@ module Aruba
 
         self
       end
-      # rubocop:enable Metrics/CyclomaticComplexity
 
       # Move a file and/or directory
       #
@@ -210,25 +220,29 @@ module Aruba
       # @param [String] destination
       #   A file or directory name. If multiple sources are given the destination
       #   needs to be a directory
-      #
-      # rubocop:disable Metrics/CyclomaticComplexity
-      # rubocop:disable Metrics/MethodLength
       def move(*args)
         args = args.flatten
         destination = args.pop
         source = args
 
         source.each do |s|
-          raise ArgumentError, "Using a fixture as source (#{source}) is not supported" if s.start_with? aruba.config.fixtures_path_prefix
+          if s.start_with? aruba.config.fixtures_path_prefix
+            raise ArgumentError, "Using a fixture as source (#{source}) is not supported"
+          end
         end
 
-        raise ArgumentError, "Using a fixture as destination (#{destination}) is not supported" if destination.start_with? aruba.config.fixtures_path_prefix
+        if destination.start_with? aruba.config.fixtures_path_prefix
+          raise ArgumentError,
+                "Using a fixture as destination (#{destination}) is not supported"
+        end
 
         source.each do |s|
           raise ArgumentError, %(The following source "#{s}" does not exist.) unless exist? s
         end
 
-        raise ArgumentError, "Multiple sources can only be copied to a directory" if source.count > 1 && exist?(destination) && !directory?(destination)
+        if source.count > 1 && exist?(destination) && !directory?(destination)
+          raise ArgumentError, 'Multiple sources can only be copied to a directory'
+        end
 
         source_paths     = source.map { |f| expand_path(f) }
         destination_path = expand_path(destination)
@@ -244,18 +258,16 @@ module Aruba
 
         self
       end
-      # rubocop:enable Metrics/MethodLength
-      # rubocop:enable Metrics/CyclomaticComplexity
 
       # Create a file with the given size
       #
       # The method does not check if file already exists. If the file name is a
       # path the method will create all neccessary directories.
       #
-      # @param [String] file_name
+      # @param [String] name
       #   The name of the file
       #
-      # @param [Integer] file_size
+      # @param [Integer] size
       #   The size of the file
       def write_fixed_size_file(name, size)
         Aruba.platform.create_fixed_size_file(expand_path(name), size, false)
@@ -277,28 +289,28 @@ module Aruba
       # Change file system  permissions of file
       #
       # @param [Octal] mode
-      #   File system mode, eg. 0755
+      #   File system mode, eg. 0o755
       #
       # @param [String] file_name
       #   Name of file to be modified. This file needs to be present to succeed
       def chmod(*args)
         args = args.flatten
 
-        options = if args.last.kind_of? Hash
+        options = if args.last.is_a? Hash
                     args.pop
                   else
                     {}
                   end
 
         mode = args.shift
-        mode = if mode.kind_of? String
+        mode = if mode.is_a? String
                  mode.to_i(8)
                else
                  mode
                end
 
-        args.each { |p| raise "Expected #{p} to be present" unless exist?(p) }
-        paths = args.map { |p| expand_path(p) }
+        args.each { |path| raise "Expected #{path} to be present" unless exist?(path) }
+        paths = args.map { |path| expand_path(path) }
 
         Aruba.platform.chmod(mode, paths, options)
 
@@ -336,13 +348,13 @@ module Aruba
       def remove(*args)
         args = args.flatten
 
-        options = if args.last.kind_of? Hash
+        options = if args.last.is_a? Hash
                     args.pop
                   else
                     {}
                   end
 
-        args = args.map { |p| expand_path(p) }
+        args = args.map { |path| expand_path(path) }
 
         Aruba.platform.rm(args, options)
       end
@@ -354,7 +366,7 @@ module Aruba
       #
       # @yield
       #   Pass the content of the given file to this block
-      def with_file_content(file, &block)
+      def with_file_content(file)
         expect(file).to be_an_existing_path
 
         content = read(file).join("\n")
@@ -370,20 +382,25 @@ module Aruba
       # @param [Array, Path] paths
       #   The paths
       #
-      # @result [FileSize]
+      # @return [FileSize]
       #   Bytes on disk
       def disk_usage(*paths)
-        expect(paths.flatten).to Aruba::Matchers.all be_an_existing_path
+        paths = paths.flatten
+        expect(paths).to Aruba::Matchers.all be_an_existing_path
+        expanded = paths.map { |path| expand_path(path) }
 
-        Aruba.platform.determine_disk_usage paths.flatten.map { |p| ArubaPath.new(expand_path(p)) }, aruba.config.physical_block_size
+        Aruba.platform.determine_disk_usage(expanded)
       end
 
       # Get size of file
       #
+      # @param [String] name
+      #   File name
+      #
       # @return [Numeric]
       #   The size of the file
       def file_size(name)
-        raise ArgumentError, "#{name} does not exist" unless exist? name
+        expect(name).to be_an_existing_file
 
         Aruba.platform.determine_file_size expand_path(name)
       end
