@@ -32,8 +32,8 @@ module Aruba
         contract = opts[:contract]
         default  = opts[:default]
 
-        fail ArgumentError, 'Either use block or default value' if block_given? && default
-        fail ArgumentError, 'contract-options is required' if contract.nil?
+        raise ArgumentError, 'Either use block or default value' if block_given? && default
+        raise ArgumentError, 'contract-options is required' if contract.nil?
 
         Contract contract
         add_option(name, block_given? ? yield(InConfigWrapper.new(known_options)) : default)
@@ -61,9 +61,8 @@ module Aruba
         contract = opts[:contract]
         default  = opts[:default]
 
-        fail ArgumentError, 'Either use block or default value' if block_given? && default
-        # fail ArgumentError, 'Either use block or default value' if !block_given? && default.nil? && default.to_s.empty?
-        fail ArgumentError, 'contract-options is required' if contract.nil?
+        raise ArgumentError, 'Either use block or default value' if block_given? && default
+        raise ArgumentError, 'contract-options is required' if contract.nil?
 
         # Add writer
         add_option(name, block_given? ? yield(InConfigWrapper.new(known_options)) : default)
@@ -72,7 +71,7 @@ module Aruba
         define_method("#{name}=") { |v| find_option(name).value = v }
 
         # Add reader
-        option_reader name, :contract => { None => contract.values.first }
+        option_reader name, contract: { None => contract.values.first }
       end
 
       private
@@ -80,7 +79,7 @@ module Aruba
       def add_option(name, value = nil)
         return if known_options.key?(name)
 
-        known_options[name] = Option.new(:name => name, :value => value)
+        known_options[name] = Option.new(name: name, value: value)
 
         self
       end
@@ -114,29 +113,13 @@ module Aruba
 
     # Make deep dup copy of configuration
     def make_copy
-      obj = self.dup
+      obj = dup
       obj.local_options = Marshal.load(Marshal.dump(local_options))
       obj.hooks         = @hooks
 
       obj
     end
 
-    # Get access to hooks
-    def hooks
-      # rubocop:disable Metrics/LineLength
-      Aruba.platform.deprecated 'The use of the "#aruba.config.hooks" is deprecated. Please use "#aruba.config.before(:name) {}" to define and "#aruba.config.before(:name, *args)" to run a hook. This method will become private in the next major version.'
-      # rubocop:enable Metrics/LineLength
-
-      @hooks
-    end
-
-    # @deprecated
-    def before_cmd(&block)
-      Aruba.platform.deprecated 'The use of the "#before_cmd"-hook is deprecated. Please define with "#before(:command) {}" instead'
-
-      before(:command, &block)
-    end
-
     # Define or run before-hook
     #
     # @param [Symbol, String] name
@@ -215,11 +198,7 @@ module Aruba
 
     # Set if name is option
     def set_if_option(name, *args)
-      if RUBY_VERSION < '1.9'
-        send("#{name}=".to_sym, *args) if option? name
-      else
-        public_send("#{name}=".to_sym, *args) if option? name
-      end
+      public_send("#{name}=".to_sym, *args) if option? name
     end
 
     private
@@ -230,7 +209,7 @@ module Aruba
     end
 
     def find_option(name)
-      fail NotImplementedError, %(Unknown option "#{name}") unless option? name
+      raise NotImplementedError, %(Unknown option "#{name}") unless option? name
 
       local_options[name]
     end
