@@ -1,7 +1,7 @@
 require 'shellwords'
 require 'aruba/colorizer'
 
-Aruba::Colorizer.coloring = false if !STDOUT.tty? && !ENV.key?("AUTOTEST")
+Aruba::Colorizer.coloring = false if !STDOUT.tty? && !ENV.key?('AUTOTEST')
 
 # Aruba
 module Aruba
@@ -21,31 +21,40 @@ module Aruba
     #
     #   before do
     #     current_example = context.example
-    #     aruba.announcer.activate :my_channel if current_example.metadata[:announce_my_channel]
+    #     if current_example.metadata[:announce_my_channel]
+    #       aruba.announcer.activate :my_channel
+    #     end
     #   end
     #
     #   Aruba.announcer.announce(:my_channel, 'my message')
     #
     class Announcer
+      # Base Announcer class
+      class BaseAnnouncer
+        def mode?(m)
+          mode == m
+        end
+      end
+
       # Announcer using Kernel.puts
-      class KernelPutsAnnouncer
+      class KernelPutsAnnouncer < BaseAnnouncer
         def announce(message)
           Kernel.puts message
         end
 
-        def mode?(m)
-          :kernel_puts == m
+        def mode
+          :kernel_puts
         end
       end
 
       # Announcer using Main#puts
-      class PutsAnnouncer
+      class PutsAnnouncer < BaseAnnouncer
         def announce(message)
           puts message
         end
 
-        def mode?(m)
-          :puts == m
+        def mode
+          :puts
         end
       end
 
@@ -55,7 +64,7 @@ module Aruba
 
       public
 
-      def initialize(*args)
+      def initialize
         @announcers = []
         @announcers << PutsAnnouncer.new
         @announcers << KernelPutsAnnouncer.new
@@ -66,56 +75,41 @@ module Aruba
         @channels          = {}
         @output_formats    = {}
 
-        @options           = args[1] || {}
-
         after_init
       end
 
       private
 
-      # rubocop:disable Metrics/MethodLength
       def after_init
         output_format :changed_configuration, proc { |n, v| format('# %s = %s', n, v) }
-        output_format :changed_environment, proc { |n, v| format('$ export %s=%s', n, Shellwords.escape(v)) }
+        output_format :changed_environment,
+                      proc { |n, v| format('$ export %s=%s', n, Shellwords.escape(v)) }
         output_format :command, '$ %s'
         output_format :directory, '$ cd %s'
-        output_format :environment, proc { |n, v| format('$ export %s=%s', n, Shellwords.escape(v)) }
-        output_format :full_environment, proc { |h| format("<<-ENVIRONMENT\n%s\nENVIRONMENT", Aruba.platform.simple_table(h)) }
-        output_format :modified_environment, proc { |n, v| format('$ export %s=%s', n, Shellwords.escape(v)) }
+        output_format :environment,
+                      proc { |n, v| format('$ export %s=%s', n, Shellwords.escape(v)) }
+        output_format :full_environment,
+                      proc { |h|
+                        format("<<-ENVIRONMENT\n%s\nENVIRONMENT",
+                               Aruba.platform.simple_table(h))
+                      }
+        output_format :modified_environment,
+                      proc { |n, v| format('$ export %s=%s', n, Shellwords.escape(v)) }
         output_format :stderr, "<<-STDERR\n%s\nSTDERR"
         output_format :stdout, "<<-STDOUT\n%s\nSTDOUT"
         output_format :command_content, "<<-COMMAND\n%s\nCOMMAND"
-        output_format :stop_signal, proc { |p, s| format('Command will be stopped with `kill -%s %s`', s, p) }
+        output_format :stop_signal,
+                      proc { |p, s|
+                        format('Command will be stopped with `kill -%s %s`', s, p)
+                      }
         output_format :timeout, '# %s-timeout: %s seconds'
         output_format :wait_time, '# %s: %s seconds'
-        output_format :command_filesystem_status, proc { |status|
-          format("<<-COMMAND FILESYSTEM STATUS\n%s\nCOMMAND FILESYSTEM STATUS",
-                 Aruba.platform.simple_table(status.to_h, :sort => false)) }
-
-        # rubocop:disable Metrics/LineLength
-        if @options[:stdout]
-          warn('The use of "@announce_stdout-instance" variable and "options[:stdout] = true" for Announcer.new is deprecated. Please use "announcer.activate(:stdout)" instead.')
-          activate :stdout
-        end
-        if @options[:stderr]
-          warn('The use of "@announce_stderr-instance" variable and "options[:stderr] = true" for Announcer.new is deprecated. Please use "announcer.activate(:stderr)" instead.')
-          activate :stderr
-        end
-        if @options[:dir]
-          warn('The use of "@announce_dir-instance" variable and "options[:dir] = true" for Announcer.new is deprecated. Please use "announcer.activate(:directory)" instead.')
-          activate :directory
-        end
-        if @options[:cmd]
-          warn('The use of "@announce_cmd-instance" variable and "options[:cmd] = true" for Announcer.new is deprecated. Please use "announcer.activate(:command)" instead.')
-          activate :command
-        end
-        if @options[:env]
-          warn('The use of "@announce_env-instance" variable and "options[:env] = true" for Announcer.new is deprecated. Please use "announcer.activate(:modified_environment)" instead.')
-          activate :modified_enviroment
-        end
-        # rubocop:enable Metrics/LineLength
+        output_format :command_filesystem_status,
+                      proc { |status|
+                        format("<<-COMMAND FILESYSTEM STATUS\n%s\nCOMMAND FILESYSTEM STATUS",
+                               Aruba.platform.simple_table(status.to_h, sort: false))
+                      }
       end
-      # rubocop:enable Metrics/MethodLength
 
       def output_format(channel, string = '%s', &block)
         output_formats[channel.to_sym] = if block_given?
@@ -139,11 +133,18 @@ module Aruba
       # @param [Symbol] m
       #   The mode to set
       def mode=(m)
-        @announcer = @announcers.find { |a| f.mode? m.to_sym }
+        @announcer = @announcers.find { |a| a.mode? m.to_sym }
 
         self
       end
 
+      # Fecth mode of announcer
+      #
+      # @return [Symbol] The current announcer mode
+      def mode
+        @announcer.mode
+      end
+
       # Check if channel is activated
       #
       # @param [Symbol] channel
@@ -154,7 +155,7 @@ module Aruba
 
       # Activate a channel
       #
-      # @param [Symbol] channel
+      # @param [Symbol] chns
       #   The name of the channel to activate
       def activate(*chns)
         chns.flatten.each { |c| channels[c.to_sym] = true }
@@ -173,7 +174,7 @@ module Aruba
       # @yield
       #   If block is given, that one is called and the return value is used as
       #   message to be announced.
-      def announce(channel, *args, &block)
+      def announce(channel, *args)
         channel = channel.to_sym
 
         the_output_format = if output_formats.key? channel
@@ -201,37 +202,6 @@ module Aruba
 
         nil
       end
-
-      # @deprecated
-      def stdout(content)
-        warn('The announcer now has a new api to activate channels. Please use this one: announce(:stdout, message)')
-        announce :stdout, content
-      end
-
-      # @deprecated
-      def stderr(content)
-        warn('The announcer now has a new api to activate channels. Please use this one: announce(:stderr, message)')
-        announce :stderr, content
-      end
-
-      # @deprecated
-      def dir(dir)
-        warn('The announcer now has a new api to activate channels. Please use this one announce(:directory, message)')
-        announce :directory, dir
-      end
-
-      # @deprecated
-      def cmd(cmd)
-        warn('The announcer now has a new api to activate channels. Please use this one announce(:command, message)')
-        announce :command, cmd
-      end
-
-      # @deprecated
-      def env(name, value)
-        warn('The announcer now has a new api to activate channels. Please use this one: announce(:changed_environment, key, value)')
-
-        announce :changed_environment, name, value
-      end
     end
   end
 end
