@@ -22,11 +22,7 @@ module Aruba
 
       public
 
-      if RUBY_VERSION >= '1.9.3'
-        def_delegators :@status, *METHODS
-      else
-        def_delegators :@status, :executable?, :ctime, :atime, :mtime, :size
-      end
+      def_delegators :@status, *METHODS
 
       def initialize(path)
         @status = File::Stat.new(path)
@@ -34,7 +30,7 @@ module Aruba
 
       # Return permissions
       def mode
-        format("%o", status.mode)[-4,4].gsub(/^0*/, '')
+        format('%o', status.mode)[-4, 4].gsub(/^0*/, '')
       end
 
       # Return owner
@@ -53,14 +49,14 @@ module Aruba
       #   A hash of values
       def to_h
         {
-          :owner      => owner,
-          :group      => group,
-          :mode       => mode,
-          :executable => executable?,
-          :ctime      => ctime,
-          :atime      => atime,
-          :mtime      => mtime,
-          :size       => size
+          owner: owner,
+          group: group,
+          mode: mode,
+          executable: executable?,
+          ctime: ctime,
+          atime: atime,
+          mtime: mtime,
+          size: size
         }
       end
     end
