@@ -9,19 +9,9 @@ module Aruba
         attr_reader :other_env, :block
 
         def initialize(other_env, &block)
-          @other_env = other_env
+          @other_env = other_env.to_h.transform_values(&:to_s)
 
-          @other_env = if RUBY_VERSION <= '1.9.3'
-                         # rubocop:disable Style/EachWithObject
-                         @other_env.to_hash.inject({}) { |a, (k, v)| a[k] = v.to_s; a }
-                         # rubocop:enable Style/EachWithObject
-                       else
-                         @other_env.to_h.each_with_object({}) { |(k, v), a| a[k] = v.to_s }
-                       end
-
-          @block = if block_given?
-                     block
-                   end
+          @block = (block if block_given?)
         end
 
         def call(env)
@@ -60,11 +50,7 @@ module Aruba
       def initialize(env = ENV)
         @actions = []
 
-        @env = if RUBY_VERSION < '2.0'
-                 env.to_hash
-               else
-                 env.to_h
-               end
+        @env = env.to_h
       end
 
       # Update environment with other en
@@ -77,7 +63,7 @@ module Aruba
       def update(other_env)
         actions << UpdateAction.new(other_env)
 
-        UnixEnvironmentVariables.new(to_h)
+        self
       end
 
       # Fetch variable from environment
@@ -137,7 +123,7 @@ module Aruba
         name  = name.to_s
         value = self[name].to_s + value.to_s
 
-        actions << UpdateAction.new(name => value )
+        actions << UpdateAction.new(name => value)
 
         value
       end
@@ -188,11 +174,7 @@ module Aruba
       # @return [Hash]
       #   A new hash from environment
       def to_h
-        if RUBY_VERSION < '2.0'
-          Marshal.load(Marshal.dump(prepared_environment.to_hash))
-        else
-          Marshal.load(Marshal.dump(prepared_environment.to_h))
-        end
+        actions.inject(hash_from_env.merge(env)) { |a, e| e.call(a) }
       end
 
       # Reset environment
@@ -204,14 +186,21 @@ module Aruba
         value
       end
 
+      def nest
+        old_actions = @actions.dup
+        yield(self)
+      ensure
+        @actions = old_actions
+      end
+
+      def self.hash_from_env
+        ENV.to_hash
+      end
+
       private
 
-      def prepared_environment
-        if RUBY_VERSION <= '1.9.3'
-          actions.inject(ENV.to_hash.merge(env)) { |a, e| e.call(a) }
-        else
-          actions.each_with_object(ENV.to_hash.merge(env)) { |e, a| a = e.call(a) }
-        end
+      def hash_from_env
+        self.class.hash_from_env
       end
     end
   end
