@@ -62,8 +62,8 @@ module Aruba
         DetermineFileSize.new.call(*args)
       end
 
-      def determine_disk_usage(*args)
-        DetermineDiskUsage.new.call(*args)
+      def determine_disk_usage(paths)
+        DetermineDiskUsage.new.call(paths)
       end
 
       def create_file(*args)
@@ -83,7 +83,7 @@ module Aruba
       end
 
       def detect_ruby(cmd)
-        if cmd =~ /^ruby\s/
+        if /^ruby\s/.match?(cmd)
           cmd.gsub(/^ruby\s/, "#{current_ruby} ")
         else
           cmd
@@ -98,20 +98,8 @@ module Aruba
         ::File.join(RbConfig::CONFIG['bindir'], RbConfig::CONFIG['ruby_install_name'])
       end
 
-      # @deprecated
-      # Add newline at the end
-      def ensure_newline(str)
-        deprecated('The use of "#ensure_newline" is deprecated. It will be removed soon')
-
-        str.chomp << "\n"
-      end
-
       def require_matching_files(pattern, base)
-        if RUBY_VERSION < '1.9.3'
-          ::Dir.glob(::File.expand_path(pattern, base)).each { |f| require File.join(File.dirname(f), File.basename(f, '.rb')) }
-        else
-          ::Dir.glob(::File.expand_path(pattern, base)).each { |f| require_relative f }
-        end
+        ::Dir.glob(::File.expand_path(pattern, base)).each { |f| require_relative f }
       end
 
       # Create directory and subdirectories
@@ -125,8 +113,7 @@ module Aruba
       def rm(paths, options = {})
         paths = Array(paths).map { |p| ::File.expand_path(p) }
 
-        FileUtils.rm_r(paths, :force => options[:force], :noop => options[:noop],
-                       :verbose => options[:verbose], :secure => options[:secure])
+        FileUtils.rm_r(paths, **options)
       end
 
       # Get current working directory
@@ -145,8 +132,7 @@ module Aruba
 
       # Touch file, directory
       def touch(args, options)
-        FileUtils.touch(args, :noop => options[:noop], :verbose => options[:verbose],
-                        :mtime => options[:mtime], :nocreate => options[:nocreate])
+        FileUtils.touch(args, **options)
       end
 
       # Copy file/directory
@@ -161,8 +147,7 @@ module Aruba
 
       # Change mode of file/directory
       def chmod(mode, args, options)
-        FileUtils.chmod_R(mode, args, :noop => options[:noop],
-                          :verbose => options[:verbose], :force => options[:force])
+        FileUtils.chmod_R(mode, args, **options)
       end
 
       # Exists and is file
@@ -202,7 +187,7 @@ module Aruba
 
       # Check if command is relative
       #
-      # @return [TrueClass, FalseClass]
+      # @return [Boolean]
       #   true
       #     * bin/command.sh
       #
@@ -210,13 +195,13 @@ module Aruba
       #     * /bin/command.sh
       #     * command.sh
       def relative_command?(path)
-        p = ArubaPath.new(path)
-        p.relative? && p.depth > 1
+        p = Pathname.new(path)
+        p.relative? && p.basename != p
       end
 
       # Check if command is relative
       #
-      # @return [TrueClass, FalseClass]
+      # @return [Boolean]
       #   true
       #     * command.sh
       #
@@ -230,30 +215,7 @@ module Aruba
 
       # Write to file
       def write_file(path, content)
-        if RUBY_VERSION < '1.9.3'
-          File.open(path, 'wb') do |f|
-            f.print content
-          end
-        else
-          File.write(path, content)
-        end
-      end
-
-      # Unescape string
-      #
-      # @param [String] string
-      #   The string which should be unescaped, e.g. the output of a command
-      #
-      # @return
-      #   The string stripped from escape sequences
-      def unescape(string, keep_ansi = true)
-        # rubocop:disable Metrics/LineLength
-        deprecated('The use of "Aruba.platform.unescape" is deprecated. Please use "#unescape_text" and "#sanitize_text" instead. But be aware it uses a different implementation')
-        # rubocop:enable Metrics/LineLength
-
-        string = string.gsub('\n', "\n").gsub('\"', '"').gsub('\e', "\e")
-        string = string.gsub(/\e\[\d+(?>(;\d+)*)m/, '') unless keep_ansi
-        string
+        File.write(path, content)
       end
 
       # Transform hash to a string table which can be output on stderr/stdout
@@ -274,6 +236,10 @@ module Aruba
       def which(program, path = ENV['PATH'])
         UnixWhich.new.call(program, path)
       end
+
+      def builtin_shell_commands
+        []
+      end
     end
   end
 end
