@@ -37,6 +37,10 @@ module Aruba
       def which(program, path = ENV['PATH'])
         WindowsWhich.new.call(program, path)
       end
+
+      def builtin_shell_commands
+        %w(cd dir echo exit set type)
+      end
     end
   end
 end
