@@ -19,7 +19,7 @@ module Aruba
     # @private
     class SpawnProcess < BasicProcess
       # Use as default launcher
-      def self.match?(mode)
+      def self.match?(_mode)
         true
       end
 
@@ -48,7 +48,9 @@ module Aruba
       #
       # @param [Numeric] startup_wait_time
       #   The amount of seconds to wait after Aruba has started a command.
-      def initialize(cmd, exit_timeout, io_wait_timeout, working_directory, environment = ENV.to_hash.dup, main_class = nil, stop_signal = nil, startup_wait_time = 0)
+      def initialize(cmd, exit_timeout, io_wait_timeout, working_directory,
+                     environment = Aruba.platform.environment_variables.hash_from_env,
+                     main_class = nil, stop_signal = nil, startup_wait_time = 0)
         super
 
         @process      = nil
@@ -61,15 +63,18 @@ module Aruba
       # @yield [SpawnProcess]
       #   Run code for process which was started
       #
-      # rubocop:disable Metrics/MethodLength
       def start
-        # rubocop:disable Metrics/LineLength
-        fail CommandAlreadyStartedError, %(Command "#{commandline}" has already been started. Please `#stop` the command first and `#start` it again. Alternatively use `#restart`.\n#{caller.join("\n")}) if started?
-        # rubocop:enable Metrics/LineLength
+        if started?
+          error_message =
+            "Command \"#{commandline}\" has already been started." \
+            ' Please `#stop` the command first and `#start` it again.' \
+            ' Alternatively use `#restart`.'
+          raise CommandAlreadyStartedError, error_message
+        end
 
         @started = true
 
-        @process = ChildProcess.build(*[command_string.to_a, arguments].flatten)
+        @process = ChildProcess.build(*command_string.to_a)
         @stdout_file = Tempfile.new('aruba-stdout-')
         @stderr_file = Tempfile.new('aruba-stderr-')
 
@@ -100,14 +105,13 @@ module Aruba
             sleep startup_wait_time
           end
         rescue ChildProcess::LaunchError => e
-          raise LaunchError, "It tried to start #{cmd}. " + e.message
+          raise LaunchError, "It tried to start #{commandline}. " + e.message
         end
 
         after_run
 
         yield self if block_given?
       end
-      # rubocop:enable Metrics/MethodLength
 
       # Access to stdin of process
       def stdin
@@ -154,14 +158,6 @@ module Aruba
         end
       end
 
-      def read_stdout
-        # rubocop:disable Metrics/LineLength
-        Aruba.platform.deprecated('The use of "#read_stdout" is deprecated. Use "#stdout" instead. To reduce the time to wait for io, pass `:wait_for_io => 0` or some suitable for your use case')
-        # rubocop:enable Metrics/LineLength
-
-        stdout(:wait_for_io => 0)
-      end
-
       def write(input)
         return if stopped?
 
@@ -175,11 +171,7 @@ module Aruba
       def close_io(name)
         return if stopped?
 
-        if RUBY_VERSION < '1.9'
-          @process.io.send(name.to_sym).close
-        else
-          @process.io.public_send(name.to_sym).close
-        end
+        @process.io.public_send(name.to_sym).close
       end
 
       # Stop command
@@ -211,18 +203,19 @@ module Aruba
             # ... and set the exit status
             wait
           else
-            @process.stop
+            begin
+              @process.stop
+            rescue Errno::EPERM # This can occur on MacOS
+              nil
+            end
           end
         end
 
-        @exit_status  = @process.exit_code
+        @exit_status = @process.exit_code
 
         @stdout_cache = read_temporary_output_file @stdout_file
         @stderr_cache = read_temporary_output_file @stderr_file
 
-        # @stdout_file = nil
-        # @stderr_file = nil
-
         @started = false
 
         @exit_status
@@ -240,11 +233,12 @@ module Aruba
       # @param [String] signal
       #   The signal, i.e. 'TERM'
       def send_signal(signal)
-        fail CommandAlreadyStoppedError, %(Command "#{commandline}" with PID "#{pid}" has already stopped.) if @process.exited?
+        error_message = %(Command "#{commandline}" with PID "#{pid}" has already stopped.)
+        raise CommandAlreadyStoppedError, error_message if @process.exited?
 
         Process.kill signal, pid
       rescue Errno::ESRCH
-        raise CommandAlreadyStoppedError, %(Command "#{commandline}" with PID "#{pid}" has already stopped.)
+        raise CommandAlreadyStoppedError, error_message
       end
 
       # Return file system stats for the given command
@@ -252,7 +246,7 @@ module Aruba
       # @return [Aruba::Platforms::FilesystemStatus]
       #   This returns a File::Stat-object
       def filesystem_status
-        Aruba.platform.filesystem_status.new(command_string.to_s)
+        Aruba.platform.filesystem_status.new(command_path)
       end
 
       # Content of command
@@ -261,21 +255,36 @@ module Aruba
       #   The content of the script/command. This might be binary output as
       #   string if your command is a binary executable.
       def content
-        File.read command_string.to_s
+        File.read command_path
+      end
+
+      def interactive?
+        true
       end
 
       private
 
       def command_string
-        # gather fully qualified path
-        cmd = Aruba.platform.which(command, environment['PATH'])
+        if command_path.nil?
+          raise LaunchError,
+                %(Command "#{command}" not found in PATH-variable "#{environment['PATH']}".)
+        end
 
-        fail LaunchError, %(Command "#{command}" not found in PATH-variable "#{environment['PATH']}".) if cmd.nil?
-
-        Aruba.platform.command_string.new(cmd)
+        Aruba.platform.command_string.new(command_path, *arguments)
       end
 
-      def wait_for_io(time_to_wait, &block)
+      def command_path
+        @command_path ||=
+          begin
+            if Aruba.platform.builtin_shell_commands.include?(command)
+              command
+            else
+              Aruba.platform.which(command, environment['PATH'])
+            end
+          end
+      end
+
+      def wait_for_io(time_to_wait)
         sleep time_to_wait
         yield
       end
@@ -286,11 +295,7 @@ module Aruba
         data = file.read
         file.close
 
-        if RUBY_VERSION >= '1.9'
-          data.force_encoding('UTF-8')
-        else
-          data
-        end
+        data.force_encoding('UTF-8')
       end
     end
   end
