@@ -14,14 +14,15 @@ RSpec.describe 'Command Matchers' do
   describe '#to_have_exit_status' do
     let(:cmd) { 'true' }
 
-    before(:each) { run_command(cmd) }
+    before { run_command(cmd) }
 
     context 'when has exit 0' do
       it { expect(last_command_started).to have_exit_status 0 }
     end
 
-    context 'when has exit 0' do
+    context 'when does not have exit 0' do
       let(:cmd) { 'false' }
+
       it { expect(last_command_started).not_to have_exit_status 0 }
     end
   end
@@ -29,14 +30,15 @@ RSpec.describe 'Command Matchers' do
   describe '#to_be_successfully_executed_' do
     let(:cmd) { 'true' }
 
-    before(:each) { run_command(cmd) }
+    before { run_command(cmd) }
 
     context 'when has exit 0' do
       it { expect(last_command_started).to be_successfully_executed }
     end
 
-    context 'when has exit 0' do
+    context 'when does not have exit 0' do
       let(:cmd) { 'false' }
+
       it { expect(last_command_started).not_to be_successfully_executed }
     end
   end
@@ -46,13 +48,14 @@ RSpec.describe 'Command Matchers' do
     let(:output) { 'hello world' }
 
     context 'when have output hello world on stdout' do
-      before(:each) { run_command(cmd) }
+      before { run_command(cmd) }
+
       it { expect(last_command_started).to have_output output }
     end
 
     context 'when multiple commands output hello world on stdout' do
       context 'and all comands must have the output' do
-        before(:each) do
+        before do
           run_command(cmd)
           run_command(cmd)
         end
@@ -61,7 +64,7 @@ RSpec.describe 'Command Matchers' do
       end
 
       context 'and any comand can have the output' do
-        before(:each) do
+        before do
           run_command(cmd)
           run_command('echo hello universe')
         end
@@ -71,28 +74,15 @@ RSpec.describe 'Command Matchers' do
     end
 
     context 'when have output hello world on stderr' do
-      before :each do
-        string = <<-EOS.strip_heredoc
-        #!/usr/bin/env bash
+      let(:cmd) { "ruby -e 'warn \"#{output}\"'" }
 
-        echo $* >&2
-        EOS
-
-        File.open(expand_path('cmd.sh'), 'w') { |f| f.puts string }
-
-        File.chmod 0o755, expand_path('cmd.sh')
-        prepend_environment_variable 'PATH', "#{expand_path('.')}#{File::PATH_SEPARATOR}"
-      end
-
-      let(:cmd) { "cmd.sh #{output}" }
-
-      before(:each) { run_command(cmd) }
+      before { run_command(cmd) }
 
       it { expect(last_command_started).to have_output output }
     end
 
     context 'when not has output' do
-      before(:each) { run_command(cmd) }
+      before { run_command(cmd) }
 
       it { expect(last_command_started).not_to have_output 'hello universe' }
     end
@@ -103,33 +93,21 @@ RSpec.describe 'Command Matchers' do
     let(:output) { 'hello world' }
 
     context 'when have output hello world on stdout' do
-      before(:each) { run_command(cmd) }
+      before { run_command(cmd) }
+
       it { expect(last_command_started).to have_output_on_stdout output }
     end
 
     context 'when have output hello world on stderr' do
-      before :each do
-        string = <<-EOS.strip_heredoc
-        #!/usr/bin/env bash
+      let(:cmd) { "ruby -e 'warn \"#{output}\"'" }
 
-        echo $* >&2
-        EOS
-
-        File.open(expand_path('cmd.sh'), 'w') { |f| f.puts string }
-
-        File.chmod 0o755, expand_path('cmd.sh')
-        prepend_environment_variable 'PATH', "#{expand_path('.')}#{File::PATH_SEPARATOR}"
-      end
-
-      let(:cmd) { "cmd.sh #{output}" }
-
-      before(:each) { run_command(cmd) }
+      before { run_command(cmd) }
 
       it { expect(last_command_started).not_to have_output_on_stdout output }
     end
 
     context 'when not has output' do
-      before(:each) { run_command(cmd) }
+      before { run_command(cmd) }
 
       it { expect(last_command_started).not_to have_output_on_stdout 'hello universe' }
     end
@@ -140,33 +118,21 @@ RSpec.describe 'Command Matchers' do
     let(:output) { 'hello world' }
 
     context 'when have output hello world on stdout' do
-      before(:each) { run_command(cmd) }
+      before { run_command(cmd) }
+
       it { expect(last_command_started).not_to have_output_on_stderr output }
     end
 
     context 'when have output hello world on stderr' do
-      before :each do
-        string = <<-EOS.strip_heredoc
-        #!/usr/bin/env bash
+      let(:cmd) { "ruby -e 'warn \"#{output}\"'" }
 
-        echo $* >&2
-        EOS
-
-        File.open(expand_path('cmd.sh'), 'w') { |f| f.puts string }
-
-        File.chmod 0o755, expand_path('cmd.sh')
-        prepend_environment_variable 'PATH', "#{expand_path('.')}#{File::PATH_SEPARATOR}"
-      end
-
-      let(:cmd) { "cmd.sh #{output}" }
-
-      before(:each) { run_command(cmd) }
+      before { run_command(cmd) }
 
       it { expect(last_command_started).to have_output_on_stderr output }
     end
 
     context 'when not has output' do
-      before(:each) { run_command(cmd) }
+      before { run_command(cmd) }
 
       it { expect(last_command_started).not_to have_output_on_stderr 'hello universe' }
     end
